-- Test company_login_attempt
set client_min_messages to warning;
create extension if not exists pgtap;
reset client_min_messages;

begin;

select plan(17);

set search_path to camper, auth, public;

select has_view('company_login_attempt');
select table_privs_are('company_login_attempt', 'guest', array []::text[]);
select table_privs_are('company_login_attempt', 'employee', array []::text[]);
select table_privs_are('company_login_attempt', 'admin', array ['SELECT']);
select table_privs_are('company_login_attempt', 'authenticator', array []::text[]);

select has_column('company_login_attempt', 'attempt_id');
select col_type_is('company_login_attempt', 'attempt_id', 'bigint');

select has_column('company_login_attempt', 'user_name');
select col_type_is('company_login_attempt', 'user_name', 'text');

select has_column('company_login_attempt', 'ip_address');
select col_type_is('company_login_attempt', 'ip_address', 'inet');

select has_column('company_login_attempt', 'success');
select col_type_is('company_login_attempt', 'success', 'boolean');

select has_column('company_login_attempt', 'attempted_at');
select col_type_is('company_login_attempt', 'attempted_at', 'timestamp with time zone');


set client_min_messages to warning;
truncate company_host cascade;
truncate company_user cascade;
truncate company cascade;
truncate auth."user" cascade;
truncate auth.login_attempt cascade;
reset client_min_messages;

insert into auth."user" (user_id, email, name, password, cookie, cookie_expires_at, lang_tag)
values (1, 'demo@tandem.blog', 'Demo', 'test', '44facbb30d8a419dfd4bfbc44a4b5539d4970148dfc84bed0e', current_timestamp + interval '1 month', 'ca')
     , (5, 'admin@tandem.blog', 'Admin', 'test', '12af4c88b528c2ad4222e3740496ecbc58e76e26f087657524', current_timestamp + interval '1 month', 'es')
     , (7, 'another@tandem.blog', 'Another Employee', 'test', default, default, default)
;

insert into company (company_id, business_name, vatin, trade_name, phone, email, web, address, city, province, postal_code, rtc_number, tourist_tax, tourist_tax_max_days, country_code, currency_code, default_lang_tag)
values (2, 'Company 2', 'XX123', '', '555-555-555', 'a@a', '', '', '', '', '', '', 60, 7, 'ES', 'EUR', 'ca')
     , (4, 'Company 4', 'XX234', '', '666-666-666', 'b@b', '', '', '', '', '', '', 60, 7, 'FR', 'USD', 'es')
;

insert into company_user (company_id, user_id, role)
values (2, 1, 'admin')
     , (4, 5, 'admin')
     , (4, 7, 'employee')
;

insert into company_host (company_id, host)
values (2, 'co2')
     , (4, 'co4')
;

prepare login_attempt as
select user_name, ip_address, success, attempted_at
from company_login_attempt
;

select login('demo@tandem.blog', 'test', '::1'::inet);
select login('demo@tandem.blog', '123', '127.0.0.1'::inet);
select login('admin@tandem.blog', '123', '192.168.1.1'::inet);
select login('admin@tandem.blog', 'test', '::1'::inet);
select login('admin@tandem.blog', 'test', '192.168.2.1'::inet);
select login('another@tandem.blog', 'test', '192.168.3.1'::inet);
select login('unknown@tandem.blog', 'test', '192.168.4.1'::inet);

select set_cookie('44facbb30d8a419dfd4bfbc44a4b5539d4970148dfc84bed0e/demo@tandem.blog', 'co2');

select bag_eq(
	'login_attempt',
	$$ values ('demo@tandem.blog', '::1'::inet, true, current_timestamp)
	        , ('demo@tandem.blog', '127.0.0.1'::inet, false, current_timestamp)
	$$,
	'Should only see login attempts from the first company'
);

reset role;

select set_cookie('12af4c88b528c2ad4222e3740496ecbc58e76e26f087657524/admin@tandem.blog', 'co4');

select bag_eq(
	'login_attempt',
	$$ values ('admin@tandem.blog', '192.168.1.1'::inet, false, current_timestamp)
	        , ('admin@tandem.blog', '::1'::inet, true, current_timestamp)
	        , ('admin@tandem.blog', '192.168.2.1'::inet, true, current_timestamp)
	        , ('another@tandem.blog', '192.168.3.1'::inet, true, current_timestamp)
	$$,
	'Should only see login_attempts from the second company'
);

reset role;


select *
from finish();

rollback;
