-- Test contact
set client_min_messages to warning;
create extension if not exists pgtap;
reset client_min_messages;

begin;

select plan(68);

set search_path to camper, auth, public;

select has_table('contact');
select has_pk('contact' );
select table_privs_are('contact', 'guest', array []::text[]);
select table_privs_are('contact', 'employee', array ['SELECT', 'INSERT', 'UPDATE', 'DELETE']);
select table_privs_are('contact', 'admin', array ['SELECT', 'INSERT', 'UPDATE', 'DELETE']);
select table_privs_are('contact', 'authenticator', array []::text[]);

select has_column('contact', 'contact_id');
select col_is_pk('contact', 'contact_id');
select col_type_is('contact', 'contact_id', 'integer');
select col_not_null('contact', 'contact_id');
select col_hasnt_default('contact', 'contact_id');

select has_column('contact', 'company_id');
select col_is_fk('contact', 'company_id');
select fk_ok('contact', 'company_id', 'company', 'company_id');
select col_type_is('contact', 'company_id', 'integer');
select col_not_null('contact', 'company_id');
select col_hasnt_default('contact', 'company_id');

select has_column('contact', 'slug');
select col_is_unique('contact', 'slug');
select col_type_is('contact', 'slug', 'uuid');
select col_not_null('contact', 'slug');
select col_has_default('contact', 'slug');
select col_default_is('contact', 'slug', 'gen_random_uuid()');

select has_column('contact', 'name');
select col_type_is('contact', 'name', 'text');
select col_not_null('contact', 'name');
select col_hasnt_default('contact', 'name');

select has_column('contact', 'id_document_type_id');
select col_is_fk('contact', 'id_document_type_id');
select fk_ok('contact', 'id_document_type_id', 'id_document_type', 'id_document_type_id');
select col_type_is('contact', 'id_document_type_id', 'character varying(1)');
select col_not_null('contact', 'id_document_type_id');
select col_hasnt_default('contact', 'id_document_type_id');

select has_column('contact', 'id_document_number');
select col_type_is('contact', 'id_document_number', 'text');
select col_not_null('contact', 'id_document_number');
select col_hasnt_default('contact', 'id_document_number');

select has_column('contact', 'address');
select col_type_is('contact', 'address', 'text');
select col_not_null('contact', 'address');
select col_hasnt_default('contact', 'address');

select has_column('contact', 'city');
select col_type_is('contact', 'city', 'text');
select col_not_null('contact', 'city');
select col_hasnt_default('contact', 'city');

select has_column('contact', 'province');
select col_type_is('contact', 'province', 'text');
select col_not_null('contact', 'province');
select col_hasnt_default('contact', 'province');

select has_column('contact', 'postal_code');
select col_type_is('contact', 'postal_code', 'text');
select col_not_null('contact', 'postal_code');
select col_hasnt_default('contact', 'postal_code');

select has_column('contact', 'country_code');
select col_is_fk('contact', 'country_code');
select col_type_is('contact', 'country_code', 'country_code');
select col_not_null('contact', 'country_code');
select col_hasnt_default('contact', 'country_code');

select has_column('contact', 'created_at');
select col_type_is('contact', 'created_at', 'timestamp with time zone');
select col_not_null('contact', 'created_at');
select col_has_default('contact', 'created_at');
select col_default_is('contact', 'created_at', 'CURRENT_TIMESTAMP');

set client_min_messages to warning;
truncate contact cascade;
truncate company_host cascade;
truncate company_user cascade;
truncate company cascade;
truncate auth."user" cascade;
reset client_min_messages;


insert into auth."user" (user_id, email, name, password, cookie, cookie_expires_at)
values (1, 'demo@tandem.blog', 'Demo', 'test', '44facbb30d8a419dfd4bfbc44a4b5539d4970148dfc84bed0e', current_timestamp + interval '1 month')
     , (5, 'admin@tandem.blog', 'Demo', 'test', '12af4c88b528c2ad4222e3740496ecbc58e76e26f087657524', current_timestamp + interval '1 month')
;

insert into company (company_id, business_name, vatin, trade_name, phone, email, web, address, city, province, postal_code, rtc_number, tourist_tax, tourist_tax_max_days, country_code, currency_code, default_lang_tag)
values (2, 'Company 2', 'XX123', '', '555-555-555', 'a@a', '', '', '', '', '', '', 60, 7, 'ES', 'EUR', 'ca')
     , (4, 'Company 4', 'XX234', '', '666-666-666', 'b@b', '', '', '', '', '', '', 60, 7, 'FR', 'USD', 'ca')
;

insert into company_user (company_id, user_id, role)
values (2, 1, 'admin')
     , (4, 5, 'admin')
;

insert into company_host (company_id, host)
values (2, 'co2')
     , (4, 'co4')
;

insert into contact (company_id, name, id_document_type_id, id_document_number, address, city, province, postal_code, country_code)
values (2, 'Contact 1', 'D', '41440443Q', 'Fake St', 'City', 'Province', '17600', 'ES')
     , (4, 'Contact 2', 'D', '41440443Q', 'Fake St', 'City', 'Province', '17600', 'ES')
;

prepare contact_data as
select company_id, name
from contact
order by company_id, name;

set role employee;
select is_empty('contact_data', 'Should show no data when cookie is not set yet');
reset role;

select set_cookie('44facbb30d8a419dfd4bfbc44a4b5539d4970148dfc84bed0e/demo@tandem.blog', 'co2');
select bag_eq(
	'contact_data',
	$$ values (2, 'Contact 1')
	$$,
	'Should only list contacts of the companies where demo@tandem.blog is user of'
);
reset role;

select set_cookie('12af4c88b528c2ad4222e3740496ecbc58e76e26f087657524/admin@tandem.blog', 'co4');
select bag_eq(
	'contact_data',
	$$ values (4, 'Contact 2')
	$$,
	'Should only list contacts of the companies where admin@tandem.blog is user of'
);
reset role;

select set_cookie('not-a-cookie', 'co2');
select throws_ok(
	'contact_data',
	'42501', 'permission denied for table contact',
	'Should not allow select to guest users'
);
reset role;

select throws_ok( $$
	insert into contact (company_id, name, id_document_type_id, id_document_number, address, city, province, postal_code, country_code)
	values (2, '   ', 'D', '41440443Q', 'Fake St', 'City', 'Province', '17600', 'ES')
	$$,
       '23514', 'new row for relation "contact" violates check constraint "name_not_empty"',
	'Should not allow contacts with blank trade name'
);


select *
from finish();

rollback;

